import { createConnection } from "mariadb";

// @ts-ignore
const SQL_ROOT_DIR: string = import.meta.dir + '/../../../sql';

async function run() {
    const connection = await createConnection({
        host: process.env.DATABASE_HOST,
        user: process.env.DATABASE_USER,
        password: process.env.DATABASE_PASSWORD,
        database: process.env.DATABASE_SCHEMA
    });

    const createUserQuery: string = await Bun.file(SQL_ROOT_DIR + '/01-users.sql').text();
    const createImagesQuery: string = await Bun.file(SQL_ROOT_DIR + '/02-images.sql').text();
    const createChannelsQuery: string = await Bun.file(SQL_ROOT_DIR + '/03-channels.sql').text();
    const createEpisodesQuery: string = await Bun.file(SQL_ROOT_DIR + '/04-episodes.sql').text();


    const results = Promise.all([
        connection.query(createUserQuery),
        connection.query(createImagesQuery),
        connection.query(createChannelsQuery),
        connection.query(createEpisodesQuery)
    ]);

    return results;
}

run()
    .then(r => {
        console.log(r);
        process.exit(0);
    })
    .catch(e => {
        console.error(e);
        process.exit(1);
    })

